@@ -28,11 +28,14 @@
 #include "discovercommon_export.h"
 #include "AbstractResourcesBackend.h"
 
+class QAction;
+
 class DISCOVERCOMMON_EXPORT AggregatedResultsStream : public ResultsStream
 {
 Q_OBJECT
 public:
     AggregatedResultsStream(const QSet<ResultsStream*>& streams);
+    ~AggregatedResultsStream();
 
 Q_SIGNALS:
     void finished();
@@ -52,9 +55,11 @@ class DISCOVERCOMMON_EXPORT ResourcesModel : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(int updatesCount READ updatesCount NOTIFY updatesCountChanged)
+    Q_PROPERTY(bool hasSecurityUpdates READ hasSecurityUpdates NOTIFY updatesCountChanged)
     Q_PROPERTY(bool isFetching READ isFetching NOTIFY fetchingChanged)
     Q_PROPERTY(QVariantList applicationBackends READ applicationBackendsVariant NOTIFY backendsChanged)
     Q_PROPERTY(AbstractResourcesBackend* currentApplicationBackend READ currentApplicationBackend WRITE setCurrentApplicationBackend NOTIFY currentApplicationBackendChanged)
+    Q_PROPERTY(QAction* updateAction READ updateAction CONSTANT)
     public:
         /** This constructor should be only used by unit tests.
          *  @p backendName defines what backend will be loaded when the backend is constructed.
@@ -65,16 +70,14 @@ class DISCOVERCOMMON_EXPORT ResourcesModel : public QObject
         
         QVector< AbstractResourcesBackend* > backends() const;
         int updatesCount() const;
+        bool hasSecurityUpdates() const;
         
         bool isBusy() const;
         bool isFetching() const;
-        QList<QAction*> messageActions() const;
         
         Q_SCRIPTABLE bool isExtended(const QString &id);
 
-        AggregatedResultsStream* findResourceByPackageName(const QUrl& search);
         AggregatedResultsStream* search(const AbstractResourcesBackend::Filters &search);
-        AbstractResource* resourceForFile(const QUrl &/*url*/);
         void checkForUpdates();
 
         QVariantList applicationBackendsVariant() const;
@@ -82,13 +85,15 @@ class DISCOVERCOMMON_EXPORT ResourcesModel : public QObject
         void setCurrentApplicationBackend(AbstractResourcesBackend* backend, bool writeConfig = true);
         AbstractResourcesBackend* currentApplicationBackend() const;
 
+        QAction* updateAction() const { return m_updateAction; }
+
     public Q_SLOTS:
         void installApplication(AbstractResource* app, const AddonList& addons);
         void installApplication(AbstractResource* app);
         void removeApplication(AbstractResource* app);
 
     Q_SIGNALS:
-        void fetchingChanged();
+        void fetchingChanged(bool isFetching);
         void allInitialized();
         void backendsChanged();
         void updatesCountChanged();
@@ -110,11 +115,14 @@ class DISCOVERCOMMON_EXPORT ResourcesModel : public QObject
         void addResourcesBackend(AbstractResourcesBackend* backend);
         void registerBackendByName(const QString& name);
         void initApplicationsBackend();
+        void slotFetching();
 
+        bool m_isFetching;
         QVector< AbstractResourcesBackend* > m_backends;
         int m_initializingBackends;
-        QList<QAction*> m_ownActions;
+        QAction* m_updateAction = nullptr;
         AbstractResourcesBackend* m_currentApplicationBackend;
+        QTimer* m_allInitializedEmitter;
 
         static ResourcesModel* s_self;
 };
